@@ -78,7 +78,6 @@
 #include "statusBar.h"
 #include "sitemanager.h"
 #include "fqterm_shortcuthelper.h"
-#include "fqterm_mini_server.h"
 #include "shortcutdialog.h"
 #include "schemadialog.h"
 #include "fqterm_ip_location.h"
@@ -86,6 +85,8 @@
 #include "defineescape.h"
 #include "uaocodec.h"
 
+#include "connect_info.h"
+
 #ifdef USE_DOTNET_STYLE
 #include "dotnetstyle.h"
 #endif //USE_DOTNET_STYLE
@@ -186,9 +187,6 @@ FQTermFrame::FQTermFrame()
 
   installEventFilter(this);
 
-  serverThread_ = new FQTermMiniServerThread();
-  if (FQTermPref::getInstance()->runServer_)
-    serverThread_->start();
 #ifdef HAVE_PYTHON
   pythonHelper_ = new FQTermPythonHelper;
 #endif
@@ -218,10 +216,6 @@ FQTermFrame::~FQTermFrame() {
   //  delete uaoCodec_;
   delete windowManager_;
   FQTermIPLocation::Destroy();
-  serverThread_->quit();
-  serverThread_->wait(1000);
-  delete serverThread_;
-  
 }
 
 //initialize setting from fqterm.cfg
@@ -330,9 +324,6 @@ void FQTermFrame::iniSetting() {
   if (FQTermPref::getInstance()->useStyleSheet_) {
     loadStyleSheetFromFile(FQTermPref::getInstance()->styleSheetFile_);
   }
-
-  strTmp = config_->getItemValue("global", "runserver");
-  FQTermPref::getInstance()->runServer_ = (strTmp != "0");
 }
 
 void FQTermFrame::loadPref() {
@@ -480,8 +471,6 @@ void FQTermFrame::saveSetting() {
   strTmp = QString(state);
   config_->setItemValue("global", "toolbarstate", strTmp);
 
-  config_->setItemValue("global", "runserver", FQTermPref::getInstance()->runServer_ ? "1" : "0");
-
   config_->save(getPath(USER_CONFIG) + "fqterm.cfg");
 }
 
@@ -649,7 +638,7 @@ void FQTermFrame::connectMenuActivated() {
   
   FQTermParam param;
 
-  // FIXME: don't know the relation with id and param setted by setItemParameter
+  // FIXME: don't know the relation with id and param set by setItemParameter
   if (loadAddress(pConf, id, param)) {
     newWindow(param, id);
   }
@@ -703,6 +692,60 @@ void FQTermFrame::disconnect() {
   }
 }
 
+static QString ssh2_info(conn_info_t *info)
+{
+	QString txt;
+	txt.append("\nhost key (SHA256): ");
+	const char *tab = "0123456789ABCDEF";
+	for (int i=0; i<32; i++) {
+		unsigned char b = info->ssh_proto_info.hash[i];
+		char hex[4] = { tab[(b>>4)], tab[b&0xf], ':', 0 };
+		if (i==31)
+			hex[2] = 0;
+		txt.append(hex);
+	}
+	txt.append(QString("\ncipher(c2s): %1\ncipher(s2c): %2")
+			.arg(info->ssh_proto_info.c2s_cipher)
+			.arg(info->ssh_proto_info.s2c_cipher));
+	if (info->ssh_proto_info.c2s_mac) {
+		txt.append(QString("\nMAC(c2s): %1")
+				.arg(info->ssh_proto_info.c2s_mac));
+	}
+	if (info->ssh_proto_info.s2c_mac) {
+		txt.append(QString("\nMAC(s2c): %1")
+				.arg(info->ssh_proto_info.s2c_mac));
+	}
+	return txt;
+}
+
+void FQTermFrame::conn_info()
+{
+	FQTermSession *sess = windowManager_->activeWindow()->getSession();
+	conn_info_t *info = sess->connectionInfo();
+	QString txt;
+	switch (info->proto) {
+		case PROTO_TELNET:
+			txt = "protocol: Telnet";
+			txt.append(QString("\nHost: %1\nPort: %2")
+					.arg(info->hostname).arg(info->port));
+			break;
+		case PROTO_LOCAL:
+			txt = "protocol: Local";
+			break;
+		case PROTO_SSH:
+			txt = QString("protocol: SSH %1")
+				.arg(info->ssh_proto_info.proto_version);
+			txt.append(QString("\nHost: %1\nPort: %2")
+					.arg(info->hostname).arg(info->port));
+			if (info->ssh_proto_info.proto_version == 2)
+				txt.append(ssh2_info(info));
+			break;
+	}
+	QMessageBox b(QMessageBox::Information, "Connection Information",
+			txt, QMessageBox::Ok, this);
+	b.exec();
+}
+
 void FQTermFrame::copy() {
   windowManager_->activeWindow()->copy();
 }
@@ -1008,16 +1051,6 @@ void FQTermFrame::bosscolor() {
 }
 
 
-void FQTermFrame::toggleServer(bool on) {
-  FQTermPref::getInstance()->runServer_ = on;
-  if (on) {
-    serverThread_->start();
-  } else {
-    serverThread_->quit();
-    serverThread_->wait(1000);
-  }
-}
-
 void FQTermFrame::themesMenuAboutToShow() {
   QVector<QChar> vectorShortcutKeys;
   menuThemes_->clear();
@@ -1351,12 +1384,6 @@ void FQTermFrame::addMainTool() {
 
   toolBarMdiTools_->addAction(getAction(FQTermShortcutHelper::QUICKLOGIN));
 
-  serverButton_ = new QToolButton(toolBarMdiTools_);
-  serverButton_->setCheckable(true);
-  serverButton_->setIcon(QPixmap(getPath(RESOURCE) + "pic/fqterm_32x32.png"));
-  serverButton_->setChecked(FQTermPref::getInstance()->runServer_);
-  FQ_VERIFY(connect(serverButton_, SIGNAL(toggled(bool)), this, SLOT(toggleServer(bool))));
-  toolBarMdiTools_->addWidget(serverButton_);
   // custom define
   toolBarSetupKeys_ = addToolBar("Custom Key");
   toolBarSetupKeys_->setObjectName("Custom Key");
@@ -1364,6 +1391,7 @@ void FQTermFrame::addMainTool() {
   // the toolbar
   toolBarMdiConnectTools_ = addToolBar("BBS operations");
   toolBarMdiConnectTools_->setObjectName("BBS operations");
+  toolBarMdiConnectTools_->addAction(getAction(FQTermShortcutHelper::CONN_INFO));
   FQTERM_ADDACTION(toolBarMdiConnectTools_, DISCONNECT, this, disconnect);
   getAction(FQTermShortcutHelper::DISCONNECT)->setEnabled(false);
   toolBarMdiConnectTools_->addSeparator();
@@ -1451,6 +1479,7 @@ void FQTermFrame::addMainMenu() {
 
   FQTERM_ADDACTION(menuFile_, CONNECT, this, connectIt);
   FQTERM_ADDACTION(menuFile_, DISCONNECT, this, disconnect);
+  FQTERM_ADDACTION(menuFile_, CONN_INFO, this, conn_info);
   menuFile_->addSeparator();
   FQTERM_ADDACTION(menuFile_, ADDRESSBOOK, this, addressBook);
   FQTERM_ADDACTION(menuFile_, QUICKLOGIN, this, quickLogin);
@@ -1617,6 +1646,7 @@ void FQTermFrame::updateMenuToolBar() {
   }
 
   // update menu
+  getAction(FQTermShortcutHelper::CONN_INFO)->setEnabled(window->isConnected());
   getAction(FQTermShortcutHelper::DISCONNECT)->setEnabled(window->isConnected());
   getAction(FQTermShortcutHelper::COPYWITHCOLOR)->setChecked(window->getSession()->param().isColorCopy_);
   getAction(FQTermShortcutHelper::RECTANGLESELECTION)->setChecked(window->getSession()->param().isRectSelect_);
@@ -1683,6 +1713,7 @@ void FQTermFrame::comboFontChanged(const QFont & font) {
 }
 
 void FQTermFrame::enableMenuToolBar(bool enable) {
+  getAction(FQTermShortcutHelper::CONN_INFO)->setEnabled(enable);
   getAction(FQTermShortcutHelper::DISCONNECT)->setEnabled(enable);
   getAction(FQTermShortcutHelper::COPY)->setEnabled(enable);
   getAction(FQTermShortcutHelper::PASTE)->setEnabled(enable);
