@@ -179,6 +179,8 @@ FQTermWindow::FQTermWindow(FQTermConfig *config, FQTermFrame *frame, FQTermParam
                     this, SLOT(articleCopied(int, const QString))));
   FQ_VERIFY(connect(session_, SIGNAL(requestUserPwd(QString*, QString*, bool*)),
                     this, SLOT(requestUserPwd(QString *, QString *, bool *))));
+  FQ_VERIFY(connect(session_, SIGNAL(warnInsecure(const QString &, bool*)),
+                    this, SLOT(warnInsecure(const QString &, bool *))));
   //connect telnet signal to slots
   // QVERIFY(connect(session_->telnet_, SIGNAL(readyRead(int)),
   //                 this, SLOT(readReady(int))));
@@ -403,7 +405,7 @@ bool FQTermWindow::event(QEvent *qevent) {
       if (keyEvent->key() == Qt::Key_Tab ||
           keyEvent->key() == Qt::Key_Backtab) {
         // Key_Tab and Key_Backtab are special, if we don't process them here,
-        // the default behavoir is to move focus. see QWidget::event.
+        // the default behavior is to move focus. see QWidget::event.
         keyPressEvent(keyEvent);
         keyEvent->accept();
         res = true;
@@ -676,6 +678,13 @@ void FQTermWindow::requestUserPwd(QString *user, QString *pwd, bool *isOK) {
   *isOK = (login.exec() == QDialog::Accepted);
 }
 
+void FQTermWindow::warnInsecure(const QString &msg, bool *isOK)
+{
+	QMessageBox mb(QMessageBox::Warning, "FQTerm", msg,
+			QMessageBox::Yes | QMessageBox::No, this);
+	*isOK = (mb.exec() == QMessageBox::Yes);
+}
+
 void FQTermWindow::ZmodemState(int type, int value, const char *status) {
   QString strMsg;
   //to be completed
