@@ -5,7 +5,8 @@
 #include <openssl/sha.h>
 #include <openssl/evp.h>
 
-#if OPENSSL_VERSION_NUMBER >= 0x10100000L
+#if OPENSSL_VERSION_NUMBER >= 0x10100000L && \
+	!defined(LIBRESSL_VERSION_NUMBER)
 #define ssh_md_ctx_new EVP_MD_CTX_new
 #define ssh_md_ctx_free EVP_MD_CTX_free
 #else
@@ -30,13 +31,18 @@ extern "C" {
 	{
 		BIGNUM *g; // generator
 		BIGNUM *p; // prime
+		BIGNUM *bn_x; /* random number */
+		int e_len;
+		unsigned char *mpint_e; /* g^x mod p */
+		int secret_len;
+		unsigned char *secret;
+		BN_CTX *ctx;
 		evp_md_t digest;
 	} SSH_DH;
 
 	void ssh_dh_free(SSH_DH*);
-	SSH_DH *ssh_dh_group1_sha1(void);
-	SSH_DH *ssh_dh_group14_sha1(void);
 	void ssh_dh_hash(SSH_DH*, const unsigned char* data, unsigned char*, size_t len);
+	int ssh_dh_compute_secret(SSH_DH*, const unsigned char *, int);
 
 	typedef SSH_DH*(*NEW_DH)(void);
 	extern const char all_dh_list[];
